@@ -1,21 +1,21 @@
 #!/bin/sh
 #
-# Copyright (C) 2000  Internet Software Consortium.
-# 
+# Copyright (C) 2000, 2001  Internet Software Consortium.
+#
 # Permission to use, copy, modify, and distribute this software for any
 # purpose with or without fee is hereby granted, provided that the above
 # copyright notice and this permission notice appear in all copies.
-# 
-# THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE CONSORTIUM DISCLAIMS
-# ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES
-# OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL INTERNET SOFTWARE
-# CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL
-# DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
-# PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
-# ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
-# SOFTWARE.
+#
+# THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE CONSORTIUM
+# DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL
+# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
+# INTERNET SOFTWARE CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT,
+# INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
+# FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
+# NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
+# WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: isc-config.sh.in,v 1.3.2.1 2000/06/28 19:49:57 gson Exp $
+# $Id: isc-config.sh.in,v 1.7.4.1 2001/01/09 22:31:08 bwelling Exp $
 
 prefix=/usr/local
 exec_prefix=${prefix}
@@ -66,7 +66,7 @@ while test $# -gt 0; do
 		echo_exec_prefix=true
 		;;
 	--version)
-		echo VERSION=9.0.0
+		echo VERSION=9.1.1
 		exit 0
 		;;
 	--cflags)
@@ -99,7 +99,7 @@ fi
 if test x"$echo_cflags" = x"true"; then
 	includes="-I${exec_prefix}/include"
 	if test x"$libdns" = x"true" -o x"$libisc" = x"true"; then
-		includes="$includes -D_REENTRANT   -pthread"
+		includes="$includes -D_REENTRANT   "
 	fi
 	echo $includes
 fi
@@ -109,7 +109,7 @@ if test x"$echo_libs" = x"true"; then
 		libs="$libs -llwres"
 	fi
 	if test x"$libdns" = x"true" ; then
-		libs="$libs -ldns "
+		libs="$libs -ldns -L/usr/lib -lcrypto"
 		needothers=true
 	fi
 	if test x"$libisc" = x"true" ; then
@@ -117,7 +117,7 @@ if test x"$echo_libs" = x"true"; then
 		needothers=true
 	fi
 	if test x"$needothers" = x"true" ; then
-		libs="$libs  -pthread "
+		libs="$libs  "
 	fi
 	echo $libs
 fi
